__all__ = [
    '__title__', '__summary__', '__url__', '__version__', '__author__',
    '__email__', '__license__', '__copyright__',
]

__title__ = 'axju'
__summary__ = 'This is my personal package'
__url__ = 'https://github.com/axju/axju'

__version__ = '0.0.3a1'

__author__ = 'Axel Juraske'
__email__ = 'axel.juraske@short-report.de'

__license__ = 'MIT'
__copyright__ = 'Copyright 2018 %s' % __author__
